aboutsummaryrefslogtreecommitdiff
path: root/gfx.h
diff options
context:
space:
mode:
Diffstat (limited to 'gfx.h')
-rw-r--r--gfx.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/gfx.h b/gfx.h
index 5bef005c08..72bfd6d336 100644
--- a/gfx.h
+++ b/gfx.h
@@ -73,11 +73,12 @@ struct ColorCycle { /* Palette cycles */
byte end;
};
-struct EnqueuedObject { /* Objects to draw */
+struct BlastObject { /* BlastObjects to draw */
uint16 a,b,c,d,e;
int16 x,y;
uint16 width,height;
uint16 j,k,l;
+ uint16 mode;
};
struct BompHeader { /* Bomp header */